@@ -44,6 +44,10 @@ if [ -e $TARGET/var/cache/apt/archives/libpthread-stubs0_* ] ; then
         extract libpthread-stubs0
 fi
 
+if [ -e $TARGET/var/cache/apt/archives/libbz2-1.0_* ] ; then
+        extract libbz2-1.0
+fi
+
 x_feign_install dpkg
 if [ "$DEB_TARGET_GNU_SYSTEM" = "gnu" ] ; then
 	x_feign_install hurd
